==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property max Maximum.
 * @property min Minimum.
 */
public data class SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs(
    public val max: Output<Int>? = null,
    public val min: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs> {
    override fun toJava():
        com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs =
        com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs.builder()
            .max(max?.applyValue({ args0 -> args0 }))
            .min(min?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs].
 */
@PulumiTagMarker
public class SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgsBuilder
internal constructor() {
    private var max: Output<Int>? = null

    private var min: Output<Int>? = null

    /**
     * @param value Maximum.
     */
    @JvmName("qesvkbhlbnaxonim")
    public suspend fun max(`value`: Output<Int>) {
        this.max = value
    }

    /**
     * @param value Minimum.
     */
    @JvmName("ybyccndppgxsfsej")
    public suspend fun min(`value`: Output<Int>) {
        this.min = value
    }

    /**
     * @param value Maximum.
     */
    @JvmName("cmagnhlvaluhpvch")
    public suspend fun max(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.max = mapped
    }

    /**
     * @param value Minimum.
     */
    @JvmName("rgaloblnonyqhkkp")
    public suspend fun min(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.min = mapped
    }

    internal fun build():
        SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs =
        SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs(
            max = max,
            min = min,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property max Maximum.
 * @property min Minimum.
 */
public data class SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs(
    public val max: Output<Int>? = null,
    public val min: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs =
        com.pulumi.aws.ec2.inputs.SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs.builder()
            .max(max?.applyValue({ args0 -> args0 }))
            .min(min?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs].
 */
@PulumiTagMarker
public class SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgsBuilder
internal constructor() {
    private var max: Output<Int>? = null

    private var min: Output<Int>? = null

    /**
     * @param value Maximum.
     */
    @JvmName("lohsjyyvhphnrkax")
    public suspend fun max(`value`: Output<Int>) {
        this.max = value
    }

    /**
     * @param value Minimum.
     */
    @JvmName("hrtngpjygnjtbwgj")
    public suspend fun min(`value`: Output<Int>) {
        this.min = value
    }

    /**
     * @param value Maximum.
     */
    @JvmName("qpdqmmkgplrgxhvu")
    public suspend fun max(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.max = mapped
    }

    /**
     * @param value Minimum.
     */
    @JvmName("ybavyrplvdsjwxxi")
    public suspend fun min(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.min = mapped
    }

    internal fun build(): SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs =
        SpotFleetRequestLaunchTemplateConfigOverrideInstanceRequirementsVcpuCountArgs(
            max = max,
            min = min,
        )
}
